require 'rails_helper'

RSpec.describe TbCommerce::Api::ProductsController, type: :controller do

  before(:each) do
    request.env["HTTP_ACCEPT"] = 'application/json'

    @category = TbCommerce::Category.create({:title => 'Clothes'})
    2.times do
      FactoryGirl.create(:tb_commerce_product, :category => @category)
    end
    2.times do
      FactoryGirl.create(:tb_commerce_product)
    end
  end

  describe 'index' do
    it 'should return a list of products' do
      get :index, :format => :json
      expect(assigns(:products).count).to eq(4)
    end
    it 'should return a list of products for the provided category' do
      get :index, :category_id => @category.id
      expect(assigns(:products).count).to eq(2)
    end
  end

  describe 'show' do
    it 'should return the product' do
      product = TbCommerce::Product.first
      get :show, :id => product.id
      expect(assigns(:product)).to eq(product)
    end

    it 'should return a 404 error' do
      get :show, :id => -1
      expect(response.status).to eq(404)
    end
  end

  describe 'skus' do
    before(:each) do
      @product = TbCommerce::Product.first
      2.times do |i|
        FactoryGirl.create(:tb_commerce_product_sku, :product => @product)
      end
      FactoryGirl.create(:tb_commerce_product_sku) # create one for another product
    end

    it 'should return SKUs for the given product' do
      get :skus, :id => @product.id
      expect(assigns(:skus).count).to eq(2)
    end

    it 'should return only SKUs that support the given options' do
      # first create an option set
      set = FactoryGirl.create(:tb_commerce_option_set, :with_options)
      @product.option_sets = [set]

      # then apply an option to one of the skus
      sku = @product.product_skus.first
      option = set.options.first
      sku.options = [option]

      # now check that we get the expected SKU back from the API
      get :skus, :id => @product.id, :options => [option.id]
      expect(assigns(:skus).count).to eq(1)
      expect(assigns(:skus).first).to eq(sku)
    end
  end

  describe 'options' do
    it 'should return the supported options'
  end

end
