require 'rails_helper'

RSpec.describe TbCommerce::ProductsController, type: :controller do

  before(:each) do
    @category = FactoryGirl.create(:tb_commerce_category)
  end

  describe "GET #index" do
    it "returns http success" do
      get :index, :category_id => @category.slug
      expect(response).to have_http_status(:success)
    end

    it 'returns a 404' do
      get :index, :category_id => 'fail'
      expect(response.status).to eq(404)
    end
  end

  describe 'search' do
    it 'should search the products' do
      product = FactoryGirl.create(:tb_commerce_product)
      get :search, :search => product.title
      expect(assigns(:products)).to eq([product])
    end
  end

  describe "GET #show" do
    it "returns http success" do
      product = FactoryGirl.create(:tb_commerce_product, :category => @category)
      get :show, :category_id => @category.slug, :id => product.slug
      expect(response).to have_http_status(:success)
    end

    it 'returns a 404' do
      get :show, :category_id => @category.slug, :id => 'fail'
      expect(response.status).to eq(404)
    end
  end

end
