require 'rails_helper'

RSpec.describe TbCommerce::Category, type: :model do

  describe '#generate_slug_from_title' do
    it 'should generate a url slug for the category' do
      category = FactoryGirl.create(:tb_commerce_category)
      expect(category.slug).to be_a(String)
    end

    it 'should also change the slug if the title changes' do
      category = FactoryGirl.create(:tb_commerce_category)
      expect{
        category.update_attribute(:title, 'New Category Title')
      }.to change(category, :slug)
    end
  end

  describe '#destroy' do
    it 'should null out foreign keys' do
      category = FactoryGirl.create(:tb_commerce_category)
      product = FactoryGirl.create(:tb_commerce_product, :category => category)
      expect{
        category.destroy()
        product.reload
      }.to change(product, :category).to(nil)
    end
  end

end
