require 'rails_helper'

RSpec.describe TbCommerce::Product, type: :model do

  describe '.search' do
    it 'should return the product for matching title' do
      product = FactoryGirl.create(:tb_commerce_product, :title => 'Hello, World!')
      expect(TbCommerce::Product.search('Hello, World!').first).to eq(product)
    end
    
    it 'should return the product for matching description' do
      product = FactoryGirl.create(:tb_commerce_product, :description => 'Hello, World!')
      expect(TbCommerce::Product.search('Hello, World!').first).to eq(product)
    end

    it 'should not return any results' do
      product = FactoryGirl.create(:tb_commerce_product)
      expect(TbCommerce::Product.search('Fail').length).to eq(0)
    end
  end

  describe '#generate_slug_from_title' do
    it 'should generate a url slug for the product' do
      product = FactoryGirl.create(:tb_commerce_product)
      expect(product.slug).to be_a(String)
    end

    it 'should also change the slug if the title changes' do
      product = FactoryGirl.create(:tb_commerce_product)
      expect{
        product.update_attribute(:title, 'New Product Title')
      }.to change(product, :slug)
    end
  end

end
